# How to use
Follow this doc: https://goinsidebr.atlassian.net/wiki/spaces/GOSUITE/pages/2382954497/Atualiza+o+DB+do+Companyprovider+Dados+Receita+Federal

## Install dependencies
Run the following command in your terminal: `pip install -r requirements.txt` in order to install all the necessary dependencies.

## Running
Run the following command in your terminal: `python process.py {files_identifier}`